@@ -1,5 +1,145 @@
 '''
-# replace this
+# cdk-threagile
+
+![Build](https://github.com/hupe1980/cdk-threagile/workflows/build/badge.svg)
+![Release](https://github.com/hupe1980/cdk-threagile/workflows/release/badge.svg)
+
+> Agile Threat Modeling as Code
+
+CDK Constructs for [threatgile](https://threagile.io/)
+
+## Installation
+
+TypeScript/JavaScript:
+
+```bash
+npm i cdktg
+```
+
+Python:
+
+```bash
+pip install cdktg
+```
+
+## How to use
+
+```typescript
+const project = new Project({
+    outdir: 'dist',
+});
+
+const model = new Model(project, 'Model Stub', {
+    title: 'Model Stub',
+    version: '1.0.0',
+    date: new Date('2020-03-31'),
+    author: new Author({
+        name: 'John Doe',
+    }),
+    businessCriticality: BusinessCriticality.IMPORTANT,
+});
+
+const someData = new DataAsset(model, 'Some Data Asset', {
+    description: 'Some Description',
+    usage: Usage.BUSINESS,
+    origin: 'Some Origin',
+    owner: 'Some Owner',
+    quantity: Quantity.MANY,
+    ciaTriad: new CIATriad({
+        confidentiality: Confidentiality.CONFIDENTIAL,
+        integrity: Integrity.CRITICAL,
+        availability: Availability.OPERATIONAL,
+    }),
+});
+
+const someTrustBoundary = new TrustBoundary(model, 'Some Trust Boundary', {
+    description: 'Some Description',
+    type: TrustBoundaryType.NETWORK_DEDICATED_HOSTER,
+});
+
+const someTechnicalAsset = new TechnicalAsset(model, 'Some Technical Asset', {
+    trustBoundary: someTrustBoundary,
+    description: 'Some Description',
+    assetType: AssetType.PROCESS,
+    usage: Usage.BUSINESS,
+    humanUse: false,
+    size: Size.COMPONENT,
+    technology: Technology.WEB_SERVICE_REST,
+    internet: false,
+    machine: Machine.VIRTUAL,
+    encryption: Encryption.NONE,
+    owner: 'Some Owner',
+    ciaTriad: new CIATriad({
+        confidentiality: Confidentiality.CONFIDENTIAL,
+        integrity: Integrity.CRITICAL,
+        availability: Availability.CRITICAL,
+    }),
+    multiTenant: false,
+    redundant: true,
+});
+
+someTechnicalAsset.processed(someData);
+
+const someOtherTechnicalAsset = new TechnicalAsset(model, 'Some Other Technical Asset', {
+    description: 'Some Description',
+    assetType: AssetType.PROCESS,
+    usage: Usage.BUSINESS,
+    humanUse: false,
+    size: Size.COMPONENT,
+    technology: Technology.WEB_SERVICE_REST,
+    internet: false,
+    machine: Machine.VIRTUAL,
+    encryption: Encryption.NONE,
+    owner: 'Some Owner',
+    ciaTriad: new CIATriad({
+        confidentiality: Confidentiality.CONFIDENTIAL,
+        integrity: Integrity.IMPORTANT,
+        availability: Availability.IMPORTANT,
+    }),
+    multiTenant: false,
+    redundant: true,
+});
+
+someOtherTechnicalAsset.processed(someData);
+
+const someTraffic = someTechnicalAsset.communicatedWith('Some Traffic', someOtherTechnicalAsset, {
+    description: 'Some Description',
+    protocol: Protocol.HTTPS,
+    authentication: Authentication.NONE,
+    authorization: Authorization.NONE,
+    vpn: false,
+    ipFiltered: false,
+    readonly: false,
+    usage: Usage.BUSINESS,
+});
+
+someTraffic.sent(someData);
+
+project.synth();
+```
+
+```output
+cdktg [command]
+
+Commands:
+  cdktg synth <filename>  synthesize the models
+  cdktg ping              ping the api
+  cdktg check             check the models
+  cdktg analyse           analyze the models
+  cdktg completion        generate completion script
+
+Options:
+  --help     Show help                                                 [boolean]
+  --version  Show version number                                       [boolean]
+```
+
+## Example
+
+See a complete [example](https://github.com/hupe1980/cdk-threagile-example).
+
+## License
+
+[MIT](LICENSE)
 '''
 import abc
 import builtins
@@ -868,40 +1008,112 @@ class Machine(enum.Enum):
     SERVERLESS = "SERVERLESS"
 
 
+class Manifest(metaclass=jsii.JSIIMeta, jsii_type="cdktg.Manifest"):
+    def __init__(self, *, outdir: typing.Optional[builtins.str] = None) -> None:
+        '''
+        :param outdir: The directory to output the threadgile model. Default: - .
+        '''
+        props = ManifestProps(outdir=outdir)
+
+        jsii.create(self.__class__, self, [props])
+
+    @jsii.member(jsii_name="fromFile") # type: ignore[misc]
+    @builtins.classmethod
+    def from_file(cls, dir: builtins.str) -> "Manifest":
+        '''
+        :param dir: -
+        '''
+        return typing.cast("Manifest", jsii.sinvoke(cls, "fromFile", [dir]))
+
+    @jsii.member(jsii_name="addModel")
+    def add_model(self, title: builtins.str, file_path: builtins.str) -> None:
+        '''
+        :param title: -
+        :param file_path: -
+        '''
+        return typing.cast(None, jsii.invoke(self, "addModel", [title, file_path]))
+
+    @jsii.member(jsii_name="save")
+    def save(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "save", []))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="data")
+    def data(self) -> typing.Mapping[builtins.str, builtins.str]:
+        return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "data"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="outdir")
+    def outdir(self) -> builtins.str:
+        '''The output directory into which models will be synthesized.'''
+        return typing.cast(builtins.str, jsii.get(self, "outdir"))
+
+
+@jsii.data_type(
+    jsii_type="cdktg.ManifestProps",
+    jsii_struct_bases=[],
+    name_mapping={"outdir": "outdir"},
+)
+class ManifestProps:
+    def __init__(self, *, outdir: typing.Optional[builtins.str] = None) -> None:
+        '''
+        :param outdir: The directory to output the threadgile model. Default: - .
+        '''
+        self._values: typing.Dict[str, typing.Any] = {}
+        if outdir is not None:
+            self._values["outdir"] = outdir
+
+    @builtins.property
+    def outdir(self) -> typing.Optional[builtins.str]:
+        '''The directory to output the threadgile model.
+
+        :default: - .
+        '''
+        result = self._values.get("outdir")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "ManifestProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 class Model(constructs.Construct, metaclass=jsii.JSIIMeta, jsii_type="cdktg.Model"):
     def __init__(
         self,
+        project: constructs.Construct,
+        id: builtins.str,
         *,
         author: Author,
         business_criticality: BusinessCriticality,
-        title: builtins.str,
         version: builtins.str,
         date: typing.Optional[datetime.datetime] = None,
+        title: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
+        :param project: -
+        :param id: -
         :param author: Author of the model.
         :param business_criticality: Business criticality of the target.
-        :param title: Title of the model.
         :param version: Version of the Threagile toolkit.
         :param date: Date of the model.
+        :param title: Title of the model.
         '''
         props = ModelProps(
             author=author,
             business_criticality=business_criticality,
-            title=title,
             version=version,
             date=date,
+            title=title,
         )
 
-        jsii.create(self.__class__, self, [props])
-
-    @jsii.member(jsii_name="synth")
-    def synth(self, outdir: typing.Optional[builtins.str] = None) -> None:
-        '''Synthesizes the model to the output directory.
-
-        :param outdir: -
-        '''
-        return typing.cast(None, jsii.invoke(self, "synth", [outdir]))
+        jsii.create(self.__class__, self, [project, id, props])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="author")
@@ -935,9 +1147,9 @@ class Model(constructs.Construct, metaclass=jsii.JSIIMeta, jsii_type="cdktg.Mode
     name_mapping={
         "author": "author",
         "business_criticality": "businessCriticality",
-        "title": "title",
         "version": "version",
         "date": "date",
+        "title": "title",
     },
 )
 class ModelProps:
@@ -946,25 +1158,26 @@ class ModelProps:
         *,
         author: Author,
         business_criticality: BusinessCriticality,
-        title: builtins.str,
         version: builtins.str,
         date: typing.Optional[datetime.datetime] = None,
+        title: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param author: Author of the model.
         :param business_criticality: Business criticality of the target.
-        :param title: Title of the model.
         :param version: Version of the Threagile toolkit.
         :param date: Date of the model.
+        :param title: Title of the model.
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "author": author,
             "business_criticality": business_criticality,
-            "title": title,
             "version": version,
         }
         if date is not None:
             self._values["date"] = date
+        if title is not None:
+            self._values["title"] = title
 
     @builtins.property
     def author(self) -> Author:
@@ -980,13 +1193,6 @@ class ModelProps:
         assert result is not None, "Required property 'business_criticality' is missing"
         return typing.cast(BusinessCriticality, result)
 
-    @builtins.property
-    def title(self) -> builtins.str:
-        '''Title of the model.'''
-        result = self._values.get("title")
-        assert result is not None, "Required property 'title' is missing"
-        return typing.cast(builtins.str, result)
-
     @builtins.property
     def version(self) -> builtins.str:
         '''Version of the Threagile toolkit.'''
@@ -1000,6 +1206,12 @@ class ModelProps:
         result = self._values.get("date")
         return typing.cast(typing.Optional[datetime.datetime], result)
 
+    @builtins.property
+    def title(self) -> typing.Optional[builtins.str]:
+        '''Title of the model.'''
+        result = self._values.get("title")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -1057,6 +1269,62 @@ class OutOfScopeProps:
         )
 
 
+class Project(constructs.Construct, metaclass=jsii.JSIIMeta, jsii_type="cdktg.Project"):
+    def __init__(self, *, outdir: typing.Optional[builtins.str] = None) -> None:
+        '''
+        :param outdir: The directory to output the threadgile model. Default: - .
+        '''
+        props = ProjectProps(outdir=outdir)
+
+        jsii.create(self.__class__, self, [props])
+
+    @jsii.member(jsii_name="synth")
+    def synth(self) -> None:
+        '''Synthesizes the model to the output directory.'''
+        return typing.cast(None, jsii.invoke(self, "synth", []))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="outdir")
+    def outdir(self) -> builtins.str:
+        '''The output directory into which models will be synthesized.'''
+        return typing.cast(builtins.str, jsii.get(self, "outdir"))
+
+
+@jsii.data_type(
+    jsii_type="cdktg.ProjectProps",
+    jsii_struct_bases=[],
+    name_mapping={"outdir": "outdir"},
+)
+class ProjectProps:
+    def __init__(self, *, outdir: typing.Optional[builtins.str] = None) -> None:
+        '''
+        :param outdir: The directory to output the threadgile model. Default: - .
+        '''
+        self._values: typing.Dict[str, typing.Any] = {}
+        if outdir is not None:
+            self._values["outdir"] = outdir
+
+    @builtins.property
+    def outdir(self) -> typing.Optional[builtins.str]:
+        '''The directory to output the threadgile model.
+
+        :default: - .
+        '''
+        result = self._values.get("outdir")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "ProjectProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.enum(jsii_type="cdktg.Protocol")
 class Protocol(enum.Enum):
     UNKNOEN = "UNKNOEN"
@@ -1721,10 +1989,14 @@ __all__ = [
     "InScope",
     "Integrity",
     "Machine",
+    "Manifest",
+    "ManifestProps",
     "Model",
     "ModelProps",
     "OutOfScope",
     "OutOfScopeProps",
+    "Project",
+    "ProjectProps",
     "Protocol",
     "Quantity",
     "Scope",
